@@ -36,10 +36,10 @@ from .literals import (
     SortOrderType,
 )
 from .type_defs import (
-    DescribeBatchPredictionsOutputResponseTypeDef,
-    DescribeDataSourcesOutputResponseTypeDef,
-    DescribeEvaluationsOutputResponseTypeDef,
-    DescribeMLModelsOutputResponseTypeDef,
+    DescribeBatchPredictionsOutputTypeDef,
+    DescribeDataSourcesOutputTypeDef,
+    DescribeEvaluationsOutputTypeDef,
+    DescribeMLModelsOutputTypeDef,
     PaginatorConfigTypeDef,
 )
 
@@ -53,7 +53,7 @@ __all__ = (
 
 class DescribeBatchPredictionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describebatchpredictionspaginator)
     """
 
@@ -70,16 +70,16 @@ class DescribeBatchPredictionsPaginator(Boto3Paginator):
         Prefix: str = None,
         SortOrder: SortOrderType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeBatchPredictionsOutputResponseTypeDef]:
+    ) -> Iterator[DescribeBatchPredictionsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describebatchpredictionspaginator)
         """
 
 
 class DescribeDataSourcesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describedatasourcespaginator)
     """
 
@@ -96,16 +96,16 @@ class DescribeDataSourcesPaginator(Boto3Paginator):
         Prefix: str = None,
         SortOrder: SortOrderType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeDataSourcesOutputResponseTypeDef]:
+    ) -> Iterator[DescribeDataSourcesOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describedatasourcespaginator)
         """
 
 
 class DescribeEvaluationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describeevaluationspaginator)
     """
 
@@ -122,16 +122,16 @@ class DescribeEvaluationsPaginator(Boto3Paginator):
         Prefix: str = None,
         SortOrder: SortOrderType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeEvaluationsOutputResponseTypeDef]:
+    ) -> Iterator[DescribeEvaluationsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describeevaluationspaginator)
         """
 
 
 class DescribeMLModelsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describemlmodelspaginator)
     """
 
@@ -148,8 +148,8 @@ class DescribeMLModelsPaginator(Boto3Paginator):
         Prefix: str = None,
         SortOrder: SortOrderType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[DescribeMLModelsOutputResponseTypeDef]:
+    ) -> Iterator[DescribeMLModelsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describemlmodelspaginator)
         """
